# Simulate Calibration Data

```{warning}
Incomplete documentation.
```

The simulation pipeline allows to simulate calibration data for various components of the Cherenkov Telescope Array Observatory (CTAO) including the simulation of calibration devices.

## Pedestal events

To generate pedestal events, including dark pedestal and flasher events, use the `simtools-simulate-pedestals` command.

## Flashers

Simulate flasher devices for camera calibration with [simtools-simulate-flasher](simulate_flasher).

## Muons

## Illuminators

- [simtools-simulate-illuminator](simulate_illuminator): Simulate illuminators for telescope throughput calibration, including optics
and camera.
